<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Program_Name</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Show all devices</source>
        <translation>Minden eszköz megjelenítése</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Format</source>
        <translation>Formázás</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="54"/>
        <source>Defaults</source>
        <translation>Alapértékek</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>msdos</source>
        <translation>msdos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>gpt</source>
        <translation>gpt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;USB eszköz kiválasztása&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="82"/>
        <source>Show partitions</source>
        <translation>Partíciók megjelenítése</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>fat32</source>
        <translation>fat32</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="122"/>
        <source>exfat</source>
        <translation>exfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>ntfs</source>
        <translation>ntfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="135"/>
        <source>Refresh drive list</source>
        <translation>Lista frissítése</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="149"/>
        <source>USB-DATA</source>
        <translation>USB-ADAT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="156"/>
        <source>File System Label</source>
        <translation>Fájlrendszer címke</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="163"/>
        <source>Partition Table Type</source>
        <translation>Partíciós tábla</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="222"/>
        <source>Quit application</source>
        <translation>Kilépés az alkalmazásból</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="225"/>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="270"/>
        <source>Display help </source>
        <translation>Súgó megjelenítése</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="273"/>
        <source>Help</source>
        <translation>Súgó</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="312"/>
        <source>About this application</source>
        <translation>Az alkalmazásról</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>About...</source>
        <translation>Névjegy...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="322"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="354"/>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="380"/>
        <source>Back</source>
        <translation>Vissza</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="178"/>
        <source>Success</source>
        <translation>Sikeres</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="178"/>
        <source>Format successful!</source>
        <translation>Formázás sikeres!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="180"/>
        <source>Failure</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="180"/>
        <source>Error encountered in the Format process</source>
        <translation>Hiba történt a formázás közben</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="211"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="211"/>
        <source>Please select a USB device to write to</source>
        <translation>Válassza ki a formázandó USB eszközt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="216"/>
        <source>These actions will destroy all data on 

</source>
        <translation>Ez minden adatot töröl a következőről

</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="216"/>
        <source>Do you wish to continue?</source>
        <translation>Szeretné folytatni?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="252"/>
        <source>About %1</source>
        <translation>%1 névjegye</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="253"/>
        <source>Version: </source>
        <translation>Verzió:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <source>Program for formatting USB devices</source>
        <translation>USB eszközök formázására szolgáló eszköz</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="257"/>
        <source>%1 License</source>
        <translation>%1 Licenc</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>%1 Help</source>
        <translation>%1 Súgó</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>License</source>
        <translation>Licenc</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="35"/>
        <location filename="../about.cpp" line="45"/>
        <source>Changelog</source>
        <translation>Változások listája</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="36"/>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <source>&amp;Close</source>
        <translation>&amp;Bezárás</translation>
    </message>
</context>
</TS>